@@ -3,7 +3,7 @@ package App::BorderStyleUtils;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-01-23'; # DATE
 our $DIST = 'App-BorderStyleUtils'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -66,34 +66,34 @@ sub show_border_style {
         if $bs->get_struct->{box_chars};
 
     my $map = {
-        A => sub { $bs->get_border_char(0, 0) },
-        B => sub { $bs->get_border_char(0, 1) },
-        C => sub { $bs->get_border_char(0, 2) },
-        D => sub { $bs->get_border_char(0, 3) },
-        E => sub { $bs->get_border_char(1, 0) },
-        F => sub { $bs->get_border_char(1, 1) },
-        G => sub { $bs->get_border_char(1, 2) },
-        H => sub { $bs->get_border_char(2, 0) },
-        I => sub { $bs->get_border_char(2, 1) },
-        J => sub { $bs->get_border_char(2, 2) },
-        K => sub { $bs->get_border_char(2, 3) },
-        a => sub { $bs->get_border_char(2, 4) },
-        b => sub { $bs->get_border_char(2, 5) },
-        L => sub { $bs->get_border_char(3, 0) },
-        M => sub { $bs->get_border_char(3, 1) },
-        N => sub { $bs->get_border_char(3, 2) },
-        O => sub { $bs->get_border_char(4, 0) },
-        P => sub { $bs->get_border_char(4, 1) },
-        Q => sub { $bs->get_border_char(4, 2) },
-        R => sub { $bs->get_border_char(4, 3) },
-        e => sub { $bs->get_border_char(4, 4) },
-        f => sub { $bs->get_border_char(4, 5) },
-        g => sub { $bs->get_border_char(4, 6) },
-        h => sub { $bs->get_border_char(4, 7) },
-        S => sub { $bs->get_border_char(5, 0) },
-        T => sub { $bs->get_border_char(5, 1) },
-        U => sub { $bs->get_border_char(5, 2) },
-        V => sub { $bs->get_border_char(5, 3) },
+        A => sub { $bs->get_border_char(0, 0) // '' },
+        B => sub { $bs->get_border_char(0, 1) // '' },
+        C => sub { $bs->get_border_char(0, 2) // '' },
+        D => sub { $bs->get_border_char(0, 3) // '' },
+        E => sub { $bs->get_border_char(1, 0) // '' },
+        F => sub { $bs->get_border_char(1, 1) // '' },
+        G => sub { $bs->get_border_char(1, 2) // '' },
+        H => sub { $bs->get_border_char(2, 0) // '' },
+        I => sub { $bs->get_border_char(2, 1) // '' },
+        J => sub { $bs->get_border_char(2, 2) // '' },
+        K => sub { $bs->get_border_char(2, 3) // '' },
+        a => sub { $bs->get_border_char(2, 4) // '' },
+        b => sub { $bs->get_border_char(2, 5) // '' },
+        L => sub { $bs->get_border_char(3, 0) // '' },
+        M => sub { $bs->get_border_char(3, 1) // '' },
+        N => sub { $bs->get_border_char(3, 2) // '' },
+        O => sub { $bs->get_border_char(4, 0) // '' },
+        P => sub { $bs->get_border_char(4, 1) // '' },
+        Q => sub { $bs->get_border_char(4, 2) // '' },
+        R => sub { $bs->get_border_char(4, 3) // '' },
+        e => sub { $bs->get_border_char(4, 4) // '' },
+        f => sub { $bs->get_border_char(4, 5) // '' },
+        g => sub { $bs->get_border_char(4, 6) // '' },
+        h => sub { $bs->get_border_char(4, 7) // '' },
+        S => sub { $bs->get_border_char(5, 0) // '' },
+        T => sub { $bs->get_border_char(5, 1) // '' },
+        U => sub { $bs->get_border_char(5, 2) // '' },
+        V => sub { $bs->get_border_char(5, 3) // '' },
     };
 
     my $table = <<'_';
@@ -132,7 +132,7 @@ App::BorderStyleUtils - CLI utilities related to border styles
 
 =head1 VERSION
 
-This document describes version 0.003 of App::BorderStyleUtils (from Perl distribution App-BorderStyleUtils), released on 2021-01-23.
+This document describes version 0.004 of App::BorderStyleUtils (from Perl distribution App-BorderStyleUtils), released on 2021-01-23.
 
 =head1 DESCRIPTION
 
